@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2022 Joël Krähemann
+ * Copyright (C) 2005-2023 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -65,12 +65,12 @@ void ags_alsa_devin_set_presets(AgsSoundcard *soundcard,
 				guint channels,
 				guint rate,
 				guint buffer_size,
-				guint format);
+				AgsSoundcardFormat format);
 void ags_alsa_devin_get_presets(AgsSoundcard *soundcard,
 				guint *channels,
 				guint *rate,
 				guint *buffer_size,
-				guint *format);
+				AgsSoundcardFormat *format);
 
 void ags_alsa_devin_list_cards(AgsSoundcard *soundcard,
 			       GList **card_id, GList **card_name);
@@ -92,7 +92,7 @@ void ags_alsa_devin_device_record_init(AgsSoundcard *soundcard,
 				       GError **error);
 
 void ags_alsa_devin_device_fill_backend_buffer(void *app_buffer,
-					       guint ags_format,
+					       AgsSoundcardFormat ags_format,
 					       guchar *backend_buffer,
 					       guint channels,
 					       guint buffer_size);
@@ -735,7 +735,7 @@ ags_alsa_devin_set_property(GObject *gobject,
   break;
   case PROP_FORMAT:
   {
-    guint format;
+    AgsSoundcardFormat format;
 
     format = g_value_get_uint(value);
 
@@ -1236,7 +1236,7 @@ ags_alsa_devin_disconnect(AgsConnectable *connectable)
  * Since: 3.13.2
  */
 gboolean
-ags_alsa_devin_test_flags(AgsAlsaDevin *alsa_devin, guint flags)
+ags_alsa_devin_test_flags(AgsAlsaDevin *alsa_devin, AgsAlsaDevinFlags flags)
 {
   gboolean retval;  
   
@@ -1269,7 +1269,7 @@ ags_alsa_devin_test_flags(AgsAlsaDevin *alsa_devin, guint flags)
  * Since: 3.13.2
  */
 void
-ags_alsa_devin_set_flags(AgsAlsaDevin *alsa_devin, guint flags)
+ags_alsa_devin_set_flags(AgsAlsaDevin *alsa_devin, AgsAlsaDevinFlags flags)
 {
   GRecMutex *alsa_devin_mutex;
 
@@ -1300,7 +1300,7 @@ ags_alsa_devin_set_flags(AgsAlsaDevin *alsa_devin, guint flags)
  * Since: 3.13.2
  */
 void
-ags_alsa_devin_unset_flags(AgsAlsaDevin *alsa_devin, guint flags)
+ags_alsa_devin_unset_flags(AgsAlsaDevin *alsa_devin, AgsAlsaDevinFlags flags)
 {  
   GRecMutex *alsa_devin_mutex;
 
@@ -1400,7 +1400,7 @@ ags_alsa_devin_set_presets(AgsSoundcard *soundcard,
 			   guint channels,
 			   guint rate,
 			   guint buffer_size,
-			   guint format)
+			   AgsSoundcardFormat format)
 {
   AgsAlsaDevin *alsa_devin;
 
@@ -1419,7 +1419,7 @@ ags_alsa_devin_get_presets(AgsSoundcard *soundcard,
 			   guint *channels,
 			   guint *rate,
 			   guint *buffer_size,
-			   guint *format)
+			   AgsSoundcardFormat *format)
 {
   AgsAlsaDevin *alsa_devin;
 
@@ -2326,8 +2326,8 @@ ags_alsa_devin_device_record_init(AgsSoundcard *soundcard,
 
 void
 ags_alsa_devin_device_fill_backend_buffer(void *app_buffer,
-					  guint ags_format,
-					  guchar *backend_buffer,
+					  AgsSoundcardFormat ags_format, 
+ 					  guchar *backend_buffer,
 					  guint channels,
 					  guint buffer_size)
 {
@@ -3353,7 +3353,7 @@ ags_alsa_devin_realloc_buffer(AgsAlsaDevin *alsa_devin)
   guint pcm_channels;
   guint buffer_size;
   guint word_size;
-  guint format;
+  AgsSoundcardFormat format;
   
   GRecMutex *alsa_devin_mutex;  
 
